==> qore-1.18.0.tar.bz2: qore-1.18.0/docs/modules/EmpathicBuildingDataProvider/html/annotated_dup.js <==
var annotated_dup =
[
    [ "EmpathicBuildingDataProvider", "namespace_empathic_building_data_provider.html", [
      [ "EmpathicBuildingDataProvider", "class_empathic_building_data_provider_1_1_empathic_building_data_provider.html", "class_empathic_building_data_provider_1_1_empathic_building_data_provider" ],
      [ "EmpathicBuildingDataProviderFactory", "class_empathic_building_data_provider_1_1_empathic_building_data_provider_factory.html", "class_empathic_building_data_provider_1_1_empathic_building_data_provider_factory" ],
      [ "EmpathicBuildingMeasurementEventType", "class_empathic_building_data_provider_1_1_empathic_building_measurement_event_type.html", "class_empathic_building_data_provider_1_1_empathic_building_measurement_event_type" ],
      [ "EmpathicBuildingMeasurementsCreateDataProvider", "class_empathic_building_data_provider_1_1_empathic_building_measurements_create_data_provider.html", "class_empathic_building_data_provider_1_1_empathic_building_measurements_create_data_provider" ],
      [ "EmpathicBuildingMeasurementsCreateRequestDataType", "class_empathic_building_data_provider_1_1_empathic_building_measurements_create_request_data_type.html", "class_empathic_building_data_provider_1_1_empathic_building_measurements_create_request_data_type" ],
      [ "EmpathicBuildingMeasurementsDataProvider", "class_empathic_building_data_provider_1_1_empathic_building_measurements_data_provider.html", "class_empathic_building_data_provider_1_1_empathic_building_measurements_data_provider" ],
      [ "SoftBoolStringType", "class_empathic_building_data_provider_1_1_soft_bool_string_type.html", "class_empathic_building_data_provider_1_1_soft_bool_string_type" ]
    ] ]
];

==> qore-1.19.0.tar.bz2: qore-1.19.0/docs/modules/EmpathicBuildingDataProvider/html/annotated_dup.js <==
var annotated_dup =
[
    [ "EmpathicBuildingDataProvider", "namespace_empathic_building_data_provider.html", [
      [ "EmpathicBuildingDataProvider", "class_empathic_building_data_provider_1_1_empathic_building_data_provider.html", "class_empathic_building_data_provider_1_1_empathic_building_data_provider" ],
      [ "EmpathicBuildingDataProviderBase", "class_empathic_building_data_provider_1_1_empathic_building_data_provider_base.html", "class_empathic_building_data_provider_1_1_empathic_building_data_provider_base" ],
      [ "EmpathicBuildingDataProviderFactory", "class_empathic_building_data_provider_1_1_empathic_building_data_provider_factory.html", "class_empathic_building_data_provider_1_1_empathic_building_data_provider_factory" ],
      [ "EmpathicBuildingMeasurementEventType", "class_empathic_building_data_provider_1_1_empathic_building_measurement_event_type.html", "class_empathic_building_data_provider_1_1_empathic_building_measurement_event_type" ],
      [ "EmpathicBuildingMeasurementsCreateDataProvider", "class_empathic_building_data_provider_1_1_empathic_building_measurements_create_data_provider.html", "class_empathic_building_data_provider_1_1_empathic_building_measurements_create_data_provider" ],
      [ "EmpathicBuildingMeasurementsCreateRequestDataType", "class_empathic_building_data_provider_1_1_empathic_building_measurements_create_request_data_type.html", "class_empathic_building_data_provider_1_1_empathic_building_measurements_create_request_data_type" ],
      [ "EmpathicBuildingMeasurementsDataProvider", "class_empathic_building_data_provider_1_1_empathic_building_measurements_data_provider.html", "class_empathic_building_data_provider_1_1_empathic_building_measurements_data_provider" ],
      [ "SoftBoolStringType", "class_empathic_building_data_provider_1_1_soft_bool_string_type.html", "class_empathic_building_data_provider_1_1_soft_bool_string_type" ]
    ] ]
];
